module CoreModels
  module I18n
    # Helper functions for I18n string selection
    module I18nHelper
      def self.available_locales
        # The order here is used to determine the 'best' language to display
        %w[en de fr es ar]

        # TODO: Re-activate this code ?
        # I18n.available_locales.map(&:to_s).sort
      end

      def self.i18n_string_for_locale(i18nstrings, locale, _create = false)
        i18n_string_for_locale = nil

        unless CoreModels::I18n::Language.find_by_iso_639_1_code(locale).nil?
          i18n_string_for_locale = i18nstrings.find_by_language_id(CoreModels::I18n::Language.find_by_iso_639_1_code(locale).id)
        end

        i18n_string_for_locale
      end

      def self.best_i18n_string(i18nstrings, requested_locale = nil)
        best_i18n_string = if requested_locale.nil?
                             i18n_string_for_locale(i18nstrings, I18n.locale)
                           else
                             i18n_string_for_locale(i18nstrings, requested_locale)
                           end

        if best_i18n_string.blank? || best_i18n_string.value.blank?
          available_locales.each do |locale|
            if best_i18n_string.blank? || best_i18n_string.value.blank?
              best_i18n_string = i18n_string_for_locale(i18nstrings,
                                                        locale)
            end
          end
        end

        if best_i18n_string.blank? || best_i18n_string.value.blank?
          best_i18n_string = i18n_string_for_locale(i18nstrings, I18n.locale,
                                                    true)
        end

        best_i18n_string
      end

      def self.init_i18n_strings(i18n_strings)
        I18nHelper.available_locales.each do |locale|
          i18n_strings << I18nString.new(
            language: CoreModels::I18n::Language.find_by_iso_639_1_code(locale),
            value: nil
          )
        end
      end

      def self.fill_i18n_strings(i18n_strings)
        I18nHelper.available_locales.each do |locale|
          i18n_string_for_locale = nil

          next if CoreModels::I18n::Language.find_by_iso_639_1_code(locale).nil?

          i18n_string_for_locale = i18n_strings.find_by_language_id(CoreModels::I18n::Language.find_by_iso_639_1_code(locale).id)

          next unless i18n_string_for_locale.nil?

          i18n_strings << I18nString.create(
            language: CoreModels::I18n::Language.find_by_iso_639_1_code(locale),
            value: ''
          )
        end
      end

      def self.destroy_i18n_strings(i18n_strings)
        i18n_strings.each do |i18n_string|
          i18n_string.destroy
        end
      end
    end
  end
end
